#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-CB02yAeJlwv2xBUSYeZbes
key:                  ghcide-2.3.0.0-CB02yAeJlwv2xBUSYeZbes
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  ed3d6fdecc7257b20a712ee01583168f
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-CB02yAeJlwv2xBUSYeZbes
depends:
    Diff-0.5-fNSHrsymP36dtk0YqFhZ1 Glob-0.10.2-DpHXJLkRYXm56ULcndyDbq
    aeson-2.2.1.0-JgWKiJCfYvV9emVBTyf17S array-0.5.6.0
    async-2.2.6-EpK7QlrOASTBz80Gb3A8ju base-4.18.2.1
    base16-bytestring-1.0.2.0-LP56PDIB6UDLEDCWqOwifx binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-GQhuCOunwpP4Wu7eC91bZR
    co-log-core-0.3.2.6-FxiHVtJAzEMCS7Nj1ybbql containers-0.6.7
    cryptohash-sha1-0.11.101.0-H8v0Pl0qwyDIqd5p8OXsjO
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-1dUzDBdAgLSANnK5bAC8CM
    dependent-sum-0.7.2.0-3qowiSNwnVRFf3RFjtqNm7 directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-5yowLAcQ4FtH7rJ4kjR336 exceptions-0.10.7
    extra-1.7.16-DDsIRNN8yrp3ezXLLBhh3F filepath-1.4.300.1
    fingertree-0.1.6.3-BO1UjMokPfw2j0fPStsRsA
    focus-1.0.3.2-f0z6GCNrs3EqcsaOTWION ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-9Fl4A0nJO1l2dZsISU1zXy
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-2fMGRGteekp5ZVQa7fvkmg
    hashable-1.4.7.0-CNoNcGLK9KJ5X5nXfJeai3
    hie-bios-0.12.0-DRFp2KzfLoTGA7gsmFAGS5
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-6eppjF5Yzmx6AtJBVfcNxs
    hls-graph-2.3.0.0-KVeGvs3Pa01Gc1uS3O12Cs
    hls-plugin-api-2.3.0.0-92dZWpH9rjHCkxcWcskXC5
    implicit-hie-0.1.4.0-Jn3737QNcbLIxUwtjiWNUT
    implicit-hie-cradle-0.5.0.1-2L1Vjsrg3YDH4uro23s8WC
    lens-5.3.4-LJxgvHYoW262GPTLIzFlhY
    list-t-1.0.5.7-63Y3RAtLABnABpRak8Y2Yq
    lsp-2.2.0.0-2YRGlho9kQSXW3ekoVbU4
    lsp-types-2.0.2.0-QoDSruF5Bj8NUukdhVW0G mtl-2.3.1
    opentelemetry-0.8.0-FU7MxgF92PK46ZE1XQ5eEV
    optparse-applicative-0.18.1.0-EpSL3bYuMS8I8b55RDM0x
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-DrhJgh2zvVyDSlphpqlv9X
    prettyprinter-ansi-terminal-1.1.3-4NBKkPa3YgEBUirxYRzZyb
    random-1.2.1.3-1Uit38DFsvW5UeAKObGtgy
    regex-tdfa-1.3.2.5-6VokBrH99ZuK2RS5akjMTl
    row-types-1.0.1.2-5RPnAzyn0UF8a1PXMxYsKb
    safe-exceptions-0.1.7.4-DgSSNMrYoU14SaVGl72cKY
    sorted-list-0.2.3.1-8otktGKUfzo87v0AC4Zlkd
    sqlite-simple-0.4.19.0-Gu0CKtiqm8ZChHrmYNufaw stm-2.5.1.0
    stm-containers-1.2.1.1-6an5Vlh8GT7Af50uU8BW0e
    syb-0.7.3-9nTxFCe6QUcL36iCSC2LiM text-2.0.2
    text-rope-0.3-5I7Pwcc6qSWHjN3BaUVYgq time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-KBv4DTXvafxB4kek08uChL
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-HfKtyefgs0b2egKrxLGXU0
    vector-0.13.2.0-7eILYIgfGZSAohY3MIpZY

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

